# coding: utf-8

"""
    FINBOURNE Access Management API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field
from finbourne_access.models.non_transitive_supervisor_role_resource import NonTransitiveSupervisorRoleResource
from finbourne_access.models.policy_id_role_resource import PolicyIdRoleResource

class RoleResourceRequest(BaseModel):
    """
    RoleResourceRequest  # noqa: E501
    """
    non_transitive_supervisor_role_resource: Optional[NonTransitiveSupervisorRoleResource] = Field(None, alias="nonTransitiveSupervisorRoleResource")
    policy_id_role_resource: Optional[PolicyIdRoleResource] = Field(None, alias="policyIdRoleResource")
    __properties = ["nonTransitiveSupervisorRoleResource", "policyIdRoleResource"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RoleResourceRequest:
        """Create an instance of RoleResourceRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of non_transitive_supervisor_role_resource
        if self.non_transitive_supervisor_role_resource:
            _dict['nonTransitiveSupervisorRoleResource'] = self.non_transitive_supervisor_role_resource.to_dict()
        # override the default output from pydantic by calling `to_dict()` of policy_id_role_resource
        if self.policy_id_role_resource:
            _dict['policyIdRoleResource'] = self.policy_id_role_resource.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RoleResourceRequest:
        """Create an instance of RoleResourceRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RoleResourceRequest.parse_obj(obj)

        _obj = RoleResourceRequest.parse_obj({
            "non_transitive_supervisor_role_resource": NonTransitiveSupervisorRoleResource.from_dict(obj.get("nonTransitiveSupervisorRoleResource")) if obj.get("nonTransitiveSupervisorRoleResource") is not None else None,
            "policy_id_role_resource": PolicyIdRoleResource.from_dict(obj.get("policyIdRoleResource")) if obj.get("policyIdRoleResource") is not None else None
        })
        return _obj
